@@ -535,7 +535,7 @@ class Element(ORM_Base):
                         q_base.c.parent_id == cls.id
                     )
             q_cte = q_base.union_all(q_rec)
-            return session.query(cls).select_from(q_cte).order_by(q_cte.c.level)
+            return session.query(cls).select_from(q_cte).order_by(q_cte.c.level).all()
     
     def __repr__(self):
         """
