@@ -3,13 +3,14 @@
 
 _multiprocess_can_split_ = True
 
+import base
+
 from nose.tools import raises
 from sqlalchemy.exc import IntegrityError
-from . import BaseTest
 
 from multivac import Project
 
-class TestProjectBase(BaseTest):
+class TestProjectBase(base.BaseTest):
     pass
 
 class TestCreate(TestProjectBase):
@@ -150,19 +151,19 @@ class TestQuery(TestProject):
         assert self.project['p2'] is r
         assert self.project['p2'].name == r.name
     
-    def test_tag_true(self):
-        r = Project.query_tags(self.session, tags={'t2': True}).all()
+    def test_tag_any_key(self):
+        r = self.session.query(Project).filter(Project.tags.any(name='t2')).all() # @UndefinedVariable
         assert len(r) == 2
         assert self.project['p1'] in r
         assert self.project['p2'] in r
     
-    def test_tag_none(self):
-        r = Project.query_tags(self.session, tags={'t4': None}).all()
+    def test_tag_any_key_none(self):
+        r = self.session.query(Project).filter(Project.tags.any(name='t4', value=None)).all() # @UndefinedVariable
         assert len(r) == 2
         assert self.project['p1'] in r
         assert self.project['p3'] in r
     
-    def test_tag_value(self):
-        r = Project.query_tags(self.session, tags={'t5': 'p3t5'}).filter_by(name='p3').all()
+    def test_tag_any_key_value(self):
+        r = self.session.query(Project).filter(Project.tags.any(name='t5', value='p3t5')).all() # @UndefinedVariable
         assert len(r) == 1
         assert self.project['p3'] in r
